@@ -423,9 +423,6 @@ var nodesSubController = function($scope, Collections, System, Metrics) {
 
               // These are the cores we _expect_ to find on this node according to the CLUSTERSTATUS
               var cores = nodes[node]['cores'];
-              if (! cores) {
-                cores = {};
-              }
               var indexSizeTotal = 0;
               var docsTotal = 0;
               var graphData = [];
@@ -467,9 +464,11 @@ var nodesSubController = function($scope, Collections, System, Metrics) {
                 graphObj['pct'] = (core['sizeInBytes'] / indexSizeTotal) * 100;
                 graphData.push(graphObj);
               }
-              cores.sort(function (a, b) {
-                return b.sizeInBytes - a.sizeInBytes
-              });
+              if (cores) {
+                cores.sort(function (a, b) {
+                  return b.sizeInBytes - a.sizeInBytes
+                });
+              }
               graphData.sort(function (a, b) {
                 return b.size - a.size
               });
@@ -561,17 +560,23 @@ var treeSubController = function($scope, Zookeeper) {
 
     $scope.showTreeLink = function(link) {
         var path = decodeURIComponent(link.replace(/.*[\\?&]path=([^&#]*).*/, "$1"));
-        Zookeeper.detail({path: path}, function(data) {
-            $scope.znode = data.znode;
-            if (data.znode.path.endsWith("/managed-schema") || data.znode.path.endsWith(".xml.bak")) {
-              $scope.lang = "xml";
-            } else {
-              var lastPathElement = data.znode.path.split( '/' ).pop();
-              var lastDotAt = lastPathElement ? lastPathElement.lastIndexOf('.') : -1;
-              $scope.lang = lastDotAt != -1 ? lastPathElement.substring(lastDotAt+1) : "txt";
-            }
-            $scope.showData = true;
-        });
+        if (path === '/security.json' && !$scope.isPermitted(permissions.SECURITY_READ_PERM)) {
+          // TODO: Set proper data here to display a warning in right panel "You lack the required role to see this file"
+          $scope.znode = {};
+          $scope.showData = false;
+        } else {
+          Zookeeper.detail({path: path}, function(data) {
+              $scope.znode = data.znode;
+              if (data.znode.path.endsWith("/managed-schema") || data.znode.path.endsWith(".xml.bak")) {
+                $scope.lang = "xml";
+              } else {
+                var lastPathElement = data.znode.path.split( '/' ).pop();
+                var lastDotAt = lastPathElement ? lastPathElement.lastIndexOf('.') : -1;
+                $scope.lang = lastDotAt != -1 ? lastPathElement.substring(lastDotAt+1) : "txt";
+              }
+              $scope.showData = true;
+          });
+        }
     };
 
     $scope.hideData = function() {
@@ -752,8 +757,6 @@ var graphSubController = function ($scope, Zookeeper) {
                                 pullReplicas: state[c].pullReplicas,
                                 replicationFactor: state[c].replicationFactor,
                                 router: state[c].router.name,
-                                maxShardsPerNode: state[c].maxShardsPerNode,
-                                autoAddReplicas: state[c].autoAddReplicas,
                                 nrtReplicas: state[c].nrtReplicas,
                                 tlogReplicas: state[c].tlogReplicas,
                                 numShards: shards.length
@@ -871,9 +874,7 @@ solrAdminApp.directive('graph', function(Constants) {
                 if (d.data.type == 'collection') {
                   tooltip = d.name + " {<br/> ";
                   tooltip += "numShards: [" + d.data.numShards + "],<br/>";
-                  tooltip += "maxShardsPerNode: [" + d.data.maxShardsPerNode + "],<br/>";
                   tooltip += "router: [" + d.data.router + "],<br/>";
-                  tooltip += "autoAddReplicas: [" + d.data.autoAddReplicas + "],<br/>";
                   tooltip += "replicationFactor: [" + d.data.replicationFactor + "],<br/>";
                   tooltip += "nrtReplicas: [" + d.data.nrtReplicas + "],<br/>";
                   tooltip += "pullReplicas: [" + d.data.pullReplicas + "],<br/>";
