@@ -30,6 +30,7 @@ solrAdminServices.factory('System',
     return $resource('admin/collections',
     {'wt':'json', '_':Date.now()}, {
     "list": {params:{action: "LIST"}},
+    "listaliases": {params:{action: "LISTALIASES"}},
     "status": {params:{action: "CLUSTERSTATUS"}},
     "add": {params:{action: "CREATE"}},
     "delete": {params:{action: "DELETE"}},
@@ -42,6 +43,11 @@ solrAdminServices.factory('System',
     "reload": {method: "GET", params:{action:"RELOAD", core: "@core"}}
     });
   }])
+.factory('ConfigSets',
+ ['$resource', function ($resource) {
+    return $resource('admin/configs', {'wt': 'json', '_': Date.now()}, {"configs": {params: {action: "LIST"}}
+    });
+ }])
 .factory('Cores',
   ['$resource', function($resource) {
     return $resource('admin/cores',
@@ -60,7 +66,7 @@ solrAdminServices.factory('System',
     return $resource('admin/info/logging', {'wt':'json', '_':Date.now()}, {
       "events": {params: {since:'0'}},
       "levels": {},
-      "setLevel": {}
+      "setLevel": {params: {nodes:'all'}}
       });
   }])
 .factory('Zookeeper',
@@ -120,6 +126,13 @@ solrAdminServices.factory('System',
       "postCsv": {headers: {'Content-type': 'application/csv'}, method: "POST", params: {handler: '@handler'}}
     });
   }])
+.factory('ParamSet',
+  ['$resource', function($resource) {
+    return $resource(':core/config/params/:name', {core: '@core', wt:'json', _:Date.now()}, {
+      "submit": {headers: {'Content-type': 'application/json'}, method: "POST"},
+      "get": {headers: {'Content-type': 'application/json'}, method: "GET"}
+    });
+  }])
 .service('FileUpload', function ($http) {
     this.upload = function(params, file, success, error){
         var url = "" + params.core + "/" + params.handler + "?";
@@ -140,6 +153,11 @@ solrAdminServices.factory('System',
         }).success(success).error(error);
     }
 })
+.filter('splitByComma', function() {
+  return function(input) {
+    return input === undefined ? input : input.split(',');
+  }
+})
 .factory('Luke',
   ['$resource', function($resource) {
     return $resource(':core/admin/luke', {core: '@core', wt:'json', _:Date.now()}, {
@@ -167,25 +185,12 @@ solrAdminServices.factory('System',
       "field": {params: {"analysis.showmatch": true}}
     });
   }])
-.factory('DataImport',
-  ['$resource', function($resource) {
-    return $resource(':core/:name', {core: '@core', name: '@name', indent:'on', wt:'json', _:Date.now()}, {
-      "config": {params: {command: "show-config"}, headers: {doNotIntercept: "true"},
-                 transformResponse: function(data) {
-                    return {config: data};
-                 }
-                },
-      "status": {params: {command: "status"}, headers: {doNotIntercept: "true"}},
-      "reload": {params: {command: "reload-config"}},
-      "post": {method: "POST",
-                headers: {'Content-type': 'application/x-www-form-urlencoded'},
-                transformRequest: function(data) { return $.param(data) }}
-    });
-  }])
 .factory('Ping',
   ['$resource', function($resource) {
     return $resource(':core/admin/ping', {wt:'json', core: '@core', ts:Date.now(), _:Date.now()}, {
      "ping": {},
+     "enable": {params:{action:"enable"}, headers: {doNotIntercept: "true"}},
+     "disable": {params:{action:"disable"}, headers: {doNotIntercept: "true"}},
      "status": {params:{action:"status"}, headers: {doNotIntercept: "true"}
     }});
   }])
@@ -263,6 +268,23 @@ solrAdminServices.factory('System',
        get: {method: "GET"}
      })
 }])
+.factory('SchemaDesigner',
+   ['$resource', function($resource) {
+     return $resource('/api/schema-designer/:path', {wt: 'json', path: '@path', _:Date.now()}, {
+       get: {method: "GET"},
+       post: {method: "POST", timeout: 90000},
+       put: {method: "PUT"},
+       postXml: {headers: {'Content-type': 'text/xml'}, method: "POST", timeout: 90000},
+       postCsv: {headers: {'Content-type': 'application/csv'}, method: "POST", timeout: 90000},
+       upload: {method: "POST", transformRequest: angular.identity, headers: {'Content-Type': undefined}, timeout: 90000}
+     })
+}])
+.factory('Security',
+    ['$resource', function($resource) {
+          return $resource('/api/cluster/security/:path', {wt: 'json', path: '@path', _:Date.now()}, {
+            get: {method: "GET"}, post: {method: "POST", timeout: 90000}
+        })
+}])
 .factory('AuthenticationService',
     ['base64', function (base64) {
         var service = {};
@@ -281,7 +303,53 @@ solrAdminServices.factory('System',
           sessionStorage.removeItem("auth.username");
           sessionStorage.removeItem("auth.wwwAuthHeader");
           sessionStorage.removeItem("auth.statusText");
+          localStorage.removeItem("auth.stateRandom");
+          sessionStorage.removeItem("auth.nonce");
         };
 
+        service.getAuthDataHeader = function () {
+          try {
+            var header64 = sessionStorage.getItem("auth.authDataHeader");
+            var headerJson = base64.decode(header64);
+            return JSON.parse(headerJson);
+          } catch (e) {
+            console.log("WARN: Wrong or missing X-Solr-AuthData header on 401 response " + e);
+            return null;
+          }
+        };
+
+        service.decodeJwtPart = function (jwtPart) {
+          try {
+            return JSON.parse(base64.urldecode(jwtPart));
+          } catch (e) {
+            console.log("WARN: Invalid format of JWT part: " + e);
+            return {};
+          }
+        };
+
+        service.isJwtCallback = function (hash) {
+          var hp = this.decodeHashParams(hash);
+          // console.log("Decoded hash as " + JSON.stringify(hp, undefined, 2)); // For debugging callbacks
+          return (hp['access_token'] && hp['token_type'] && hp['state']) || hp['error'];
+        };
+        
+        service.decodeHashParams = function(hash) {
+          // access_token, token_type, expires_in, state
+          if (hash == null || hash.length === 0) {
+            return {};
+          }
+          var params = {};
+          var parts = hash.split("&");
+          for (var p in parts) {
+            var kv = parts[p].split("=");
+            if (kv.length === 2) {
+              params[kv[0]] = decodeURIComponent(kv[1]);
+            } else {
+              console.log("Invalid callback URI, got parameter " + parts[p] + " but expected key=value");
+            }
+          }
+          return params;
+        };
+        
         return service;
       }]);
